package de.intevation.flys.artifacts.states;

import java.util.List;

import org.apache.log4j.Logger;

import de.intevation.artifacts.CallContext;

import de.intevation.artifactdatabase.state.Facet;

import de.intevation.flys.artifacts.FLYSArtifact;
import de.intevation.flys.artifacts.WINFOArtifact;
import de.intevation.flys.artifacts.model.FacetTypes;
import de.intevation.flys.artifacts.model.WaterlevelFacet;
import de.intevation.flys.artifacts.model.WQKms;

import de.intevation.flys.artifacts.model.DataFacet;


public class WaterlevelState
extends      DefaultState
implements   FacetTypes
{
    /** The logger that is used in this state.*/
    private static Logger logger = Logger.getLogger(WaterlevelState.class);


    @Override
    public Object computeAdvance(
        FLYSArtifact artifact,
        String       hash,
        CallContext  context,
        List<Facet>  facets, 
        Object       old
    ) {
        WINFOArtifact winfo = (WINFOArtifact)artifact;

        WQKms [] res;

        if (old instanceof WQKms []) {
            res = (WQKms [])old;
        }
        else {
            res = winfo.getWaterlevelData();
            if (res == null) {
                logger.debug("No results given.");
                return null;
            }
        }

        if (facets == null) {
            return res;
        }

        for (int i = 0; i < res.length; i++) {
            String nameW = null;
            String nameQ = null;

            if (winfo.isQ()) {
                nameQ = res[i].getName();
                nameW = "W(" + nameQ + ")";
            }
            else {
                nameW = res[i].getName();
                nameQ = "Q(" + nameQ + ")";
            }

            logger.debug("Create facet: " + nameW);
            logger.debug("Create facet: " + nameQ);

            Facet w = new WaterlevelFacet(i, LONGITUDINAL_W, nameW);
            Facet q = new WaterlevelFacet(i, LONGITUDINAL_Q, nameQ);

            facets.add(w);
            facets.add(q);
        }

        if (res.length > 0) {
            Facet wst = new DataFacet(WST, "WST data");
            Facet csv = new DataFacet(CSV, "CSV data");

            facets.add(wst);
            facets.add(csv);
        }

        return res;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
